@@ -24,7 +24,15 @@ height
 greater
 than
 width</source>
-        <translation type="unfinished"></translation>
+        <translation>დასაწოლი
+ღილაკის
+გადართვა
+
+უფრო
+დიდი
+სიმაღლით
+ვიდრე
+სიგანით</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="95"/>
@@ -36,14 +44,15 @@ width</source>
         <location filename="../../KvantumPreviewBase.ui" line="112"/>
         <location filename="../../KvantumPreviewBase.ui" line="128"/>
         <source>Toggle push button</source>
-        <translation type="unfinished"></translation>
+        <translation>გადამრთველი ღილაკი</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="141"/>
         <location filename="../../KvantumPreviewBase.ui" line="152"/>
         <source>Multi-line
  push button</source>
-        <translation type="unfinished"></translation>
+        <translation>მრავალხაზიანი
+ღილაკი</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="160"/>
@@ -57,7 +66,8 @@ with 32px folder icon</source>
         <location filename="../../KvantumPreviewBase.ui" line="224"/>
         <source>Default
 push button</source>
-        <translation type="unfinished"></translation>
+        <translation>ნაგულისხმევი
+ღილაკი</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="266"/>
@@ -134,7 +144,7 @@ beside text</source>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="366"/>
         <source>Push button with menu</source>
-        <translation type="unfinished"></translation>
+        <translation>დასაჭერი ღილაკი მენიუთი</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="415"/>
@@ -163,14 +173,15 @@ width</source>
         <location filename="../../KvantumPreviewBase.ui" line="846"/>
         <location filename="../../KvantumPreviewBase.ui" line="859"/>
         <source>Simple radio button</source>
-        <translation type="unfinished"></translation>
+        <translation>უბრალო გადამრთველი ღილაკი</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="869"/>
         <location filename="../../KvantumPreviewBase.ui" line="880"/>
         <source>Multi-line
 radio button</source>
-        <translation type="unfinished"></translation>
+        <translation>მრავალხაზიანი
+გადამრთველი ღილაკი</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="891"/>
@@ -182,26 +193,27 @@ radio button</source>
         <location filename="../../KvantumPreviewBase.ui" line="940"/>
         <location filename="../../KvantumPreviewBase.ui" line="953"/>
         <source>Simple check box</source>
-        <translation type="unfinished"></translation>
+        <translation>უბრალო თოლია</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="963"/>
         <location filename="../../KvantumPreviewBase.ui" line="974"/>
         <source>Multi-line
 check box</source>
-        <translation type="unfinished"></translation>
+        <translation>მრავალხაზიანი
+თოლია</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="982"/>
         <location filename="../../KvantumPreviewBase.ui" line="995"/>
         <source>Tri-state check box</source>
-        <translation type="unfinished"></translation>
+        <translation>სამმდგოარეობიანი თოლია</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1005"/>
         <location filename="../../KvantumPreviewBase.ui" line="1019"/>
         <source>Check box with icon</source>
-        <translation type="unfinished"></translation>
+        <translation>თოლია ხატულათი</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1075"/>
@@ -216,37 +228,37 @@ check box</source>
         <location filename="../../KvantumPreviewBase.ui" line="1594"/>
         <location filename="../../KvantumPreviewBase.ui" line="1607"/>
         <source>Frameless (no difference)</source>
-        <translation type="unfinished"></translation>
+        <translation>უჩარჩოო (სხვაობის გარეშე)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1110"/>
         <location filename="../../KvantumPreviewBase.ui" line="1149"/>
         <source>Standard combo box</source>
-        <translation type="unfinished"></translation>
+        <translation>სტანდარტული ველი სიით</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1119"/>
         <location filename="../../KvantumPreviewBase.ui" line="1158"/>
         <source>Standard combo box 1</source>
-        <translation type="unfinished"></translation>
+        <translation>სტანდარტული ჩამოსაშლელი სია 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1127"/>
         <location filename="../../KvantumPreviewBase.ui" line="1166"/>
         <source>Standard combo box 2</source>
-        <translation type="unfinished"></translation>
+        <translation>სტანდარტული ჩამოსაშლელი სია 2</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1132"/>
         <location filename="../../KvantumPreviewBase.ui" line="1171"/>
         <source>Standard combo box 3</source>
-        <translation type="unfinished"></translation>
+        <translation>სტანდარტული ჩამოსაშლელი სია 3</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1137"/>
         <location filename="../../KvantumPreviewBase.ui" line="1176"/>
         <source>Standard combo box 4</source>
-        <translation type="unfinished"></translation>
+        <translation>სტანდარტული ჩამოსაშლელი სია 4</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1197"/>
@@ -332,31 +344,31 @@ check box</source>
         <location filename="../../KvantumPreviewBase.ui" line="1331"/>
         <location filename="../../KvantumPreviewBase.ui" line="1374"/>
         <source>Editable combo box</source>
-        <translation type="unfinished"></translation>
+        <translation>ჩასწორებადი სიის ველი</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1340"/>
         <location filename="../../KvantumPreviewBase.ui" line="1383"/>
         <source>Editable combo box 1</source>
-        <translation type="unfinished"></translation>
+        <translation>ჩასწორებადი ჩამოსაშლელი სია 1</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1349"/>
         <location filename="../../KvantumPreviewBase.ui" line="1392"/>
         <source>Editable combo box 2</source>
-        <translation type="unfinished"></translation>
+        <translation>ჩასწორებადი ჩამოსაშლელი სია 2</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1354"/>
         <location filename="../../KvantumPreviewBase.ui" line="1397"/>
         <source>Editable combo box 3</source>
-        <translation type="unfinished"></translation>
+        <translation>ჩასწორებადი ჩამოსაშლელი სია 3</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1359"/>
         <location filename="../../KvantumPreviewBase.ui" line="1402"/>
         <source>Editable combo box 4</source>
-        <translation type="unfinished"></translation>
+        <translation>ჩასწორებადი ჩამოსაშლელი სია 4</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="1571"/>
@@ -504,7 +516,7 @@ check box</source>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2473"/>
         <source>Page 1 (disabled)</source>
-        <translation type="unfinished"></translation>
+        <translation>გვერდი 1 (გამორთულია)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2485"/>
@@ -518,7 +530,7 @@ check box</source>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2491"/>
         <source>Page 2 (disabled)</source>
-        <translation type="unfinished"></translation>
+        <translation>გვერდი 2 (გამორთულია)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2525"/>
@@ -542,12 +554,12 @@ check box</source>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2563"/>
         <source>Stack widget (page1)</source>
-        <translation type="unfinished"></translation>
+        <translation>სტეკის ვიჯეტი (გვერდი1)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2577"/>
         <source>Stack Widget (page2)</source>
-        <translation type="unfinished"></translation>
+        <translation>სტეკის ვიჯეტი (გვერდი2)</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2594"/>
@@ -562,7 +574,7 @@ check box</source>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2689"/>
         <source>Checkable group box</source>
-        <translation type="unfinished"></translation>
+        <translation>ჩართვადი ჯგუფური ველი</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="2724"/>
@@ -627,7 +639,7 @@ check box</source>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="3083"/>
         <source>Toggle layout direction</source>
-        <translation type="unfinished"></translation>
+        <translation>განლაგების მიმართულების გადართვა</translation>
     </message>
     <message>
         <location filename="../../KvantumPreviewBase.ui" line="3095"/>
