@@ -1195,8 +1195,8 @@ hacks_spec ThemeConfig::getHacksSpec() const
   v = getValue(KSL("Hacks"),KSL("centered_forms"));
   r.centered_forms = v.toBool();
 
-  v = getValue(KSL("Hacks"),KSL("kinetic_scrolling"));
-  r.kinetic_scrolling = v.toBool();
+  /*v = getValue(KSL("Hacks"),KSL("kinetic_scrolling"));
+  r.kinetic_scrolling = v.toBool();*/
 
   v = getValue(KSL("Hacks"),KSL("noninteger_translucency"));
   r.noninteger_translucency = v.toBool();
